@@ -1,5 +1,8 @@
 """This is an example settings.py file."""
 
+import os
+
+
 # specify which of your DBs will hold the data created by pylytics
 pylytics_db = "example"
 
@@ -13,5 +16,4 @@ DATABASES = {
     }
 }
 
-# Only used for pylytics.plugins.nameko
-NAMEKO_AMQP_URI = 'amqp://pylytics:pylytics@localhost:5672/pylytics'
+CLIENT_CONFIG = os.path.join(os.path.dirname(__file__), 'client.cnf')
